#
# Configuration file for using the XML library in GNOME applications
#
prefix="/opt/concourse/worker/volumes/live/3135ecdb-9e6e-428d-4cdc-fa1dbee33049/volume/libxmlsec1_1636111252039/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_plac"
exec_prefix="${prefix}"
libdir="${exec_prefix}/lib"
includedir="${prefix}/include"

XMLSEC_LIBDIR="${exec_prefix}/lib"
XMLSEC_INCLUDEDIR=" -D__XMLSEC_FUNCTION__=__func__ -DXMLSEC_NO_SIZE_T -DXMLSEC_NO_GOST=1 -DXMLSEC_NO_GOST2012=1 -DXMLSEC_DL_LIBLTDL=1 -I${prefix}/include/xmlsec1   -I/opt/concourse/worker/volumes/live/3135ecdb-9e6e-428d-4cdc-fa1dbee33049/volume/libxmlsec1_1636111252039/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_plac/include/libxml2 -I/opt/concourse/worker/volumes/live/3135ecdb-9e6e-428d-4cdc-fa1dbee33049/volume/libxmlsec1_1636111252039/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_plac/include -I/opt/concourse/worker/volumes/live/3135ecdb-9e6e-428d-4cdc-fa1dbee33049/volume/libxmlsec1_1636111252039/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_plac/include/libxml2 -I/opt/concourse/worker/volumes/live/3135ecdb-9e6e-428d-4cdc-fa1dbee33049/volume/libxmlsec1_1636111252039/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_plac/include  -I/opt/concourse/worker/volumes/live/3135ecdb-9e6e-428d-4cdc-fa1dbee33049/volume/libxmlsec1_1636111252039/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_plac/include -I/opt/concourse/worker/volumes/live/3135ecdb-9e6e-428d-4cdc-fa1dbee33049/volume/libxmlsec1_1636111252039/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_plac/include/openssl -DXMLSEC_CRYPTO_OPENSSL=1"
XMLSEC_LIBS="-L${exec_prefix}/lib -lxmlsec1-openssl -lxmlsec1 -lltdl  -lxml2 -L/opt/concourse/worker/volumes/live/3135ecdb-9e6e-428d-4cdc-fa1dbee33049/volume/libxmlsec1_1636111252039/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_plac/lib -lxslt -lxml2 -lpthread -liconv -licui18n -licuuc -licudata -lm  -L/opt/concourse/worker/volumes/live/3135ecdb-9e6e-428d-4cdc-fa1dbee33049/volume/libxmlsec1_1636111252039/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_plac/lib -lcrypto "
MODULE_VERSION="xmlsec-1.2.32-openssl"

